lambdaisland.native-image

Builds GraalVM native images from deps.edn projects.

Builds GraalVM native images from deps.edn projects.
raw docstring

-mainclj

(-main & args)
source

buildclj

(build main-ns
       graal-args
       {:keys [precompile native-image-path compile-path] :as opts})
source

cmdclj

(cmd {:keys [native-image-path main-ns] :lambdaisland.cli/keys [argv] :as opts})

Build a native image, with main-ns as entry point.

Build a native image, with `main-ns` as entry point.
sourceraw docstring

exec-native-imageclj

(exec-native-image opts cp main {:keys [native-image-path echo]})

Executes native-image (bin) with opts, specifying a classpath, main/entrypoint class, and destination path.

Executes native-image (bin) with opts, specifying a classpath,
main/entrypoint class, and destination path.
sourceraw docstring

flagsclj

source

merged-depsclj

(merged-deps)

Merges install, user, local deps.edn maps left-to-right.

Merges install, user, local deps.edn maps left-to-right.
sourceraw docstring

native-image-bin-pathclj

(native-image-bin-path)
source

native-image-classpathclj

(native-image-classpath)

Returns the current tools.deps classpath string, minus clj.native-image and plus compile-path.

Returns the current tools.deps classpath string, minus clj.native-image and plus *compile-path*.
sourceraw docstring

prep-compile-pathclj

(prep-compile-path)
source

shclj

(sh bin & args)

Launches a process with optional args, returning exit code. Prints stdout & stderr.

Launches a process with optional args, returning exit code.
Prints stdout & stderr.
sourceraw docstring

windows?clj

source

cljdoc builds & hosts documentation for Clojure/Script libraries