Builds GraalVM native images from deps.edn projects.
Builds GraalVM native images from deps.edn projects.
(build main-ns
graal-args
{:keys [precompile native-image-path compile-path] :as opts})(cmd {:keys [native-image-path main-ns] :lambdaisland.cli/keys [argv] :as opts})Build a native image, with main-ns as entry point.
Build a native image, with `main-ns` as entry point.
(exec-native-image opts cp main {:keys [native-image-path echo]})Executes native-image (bin) with opts, specifying a classpath, main/entrypoint class, and destination path.
Executes native-image (bin) with opts, specifying a classpath, main/entrypoint class, and destination path.
(merged-deps)Merges install, user, local deps.edn maps left-to-right.
Merges install, user, local deps.edn maps left-to-right.
(native-image-classpath)Returns the current tools.deps classpath string, minus clj.native-image and plus compile-path.
Returns the current tools.deps classpath string, minus clj.native-image and plus *compile-path*.
(sh bin & args)Launches a process with optional args, returning exit code. Prints stdout & stderr.
Launches a process with optional args, returning exit code. Prints stdout & stderr.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |